==> RMAPPER_1.0.0.zip: RMAPPER/doc/readMAPPER.R <==
###################################################
### chunk number 1: setup
###################################################
#line 31 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp1IhW1u/R.INSTALL3bbb6356/RMAPPER/inst/doc/readMAPPER.Rnw"
library(RMAPPER)
options(warn=-1, width=75, digits=2, scipen=3,  "prompt" = "R> ", "continue" = " ")


###################################################
### chunk number 2: install eval=FALSE
###################################################
## #line 48 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp1IhW1u/R.INSTALL3bbb6356/RMAPPER/inst/doc/readMAPPER.Rnw"
##  library(RMAPPER)


###################################################
### chunk number 3: factortable eval=FALSE
###################################################
## #line 60 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp1IhW1u/R.INSTALL3bbb6356/RMAPPER/inst/doc/readMAPPER.Rnw"
##  rmapperFactorTable("*")


###################################################
### chunk number 4: AbaA eval=FALSE
###################################################
## #line 65 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp1IhW1u/R.INSTALL3bbb6356/RMAPPER/inst/doc/readMAPPER.Rnw"
##  rmapperFactorTable("AbaA")


###################################################
### chunk number 5: Ab eval=FALSE
###################################################
## #line 70 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp1IhW1u/R.INSTALL3bbb6356/RMAPPER/inst/doc/readMAPPER.Rnw"
##  rmapperFactorTable("Ab")


###################################################
### chunk number 6: example1
###################################################
#line 78 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp1IhW1u/R.INSTALL3bbb6356/RMAPPER/inst/doc/readMAPPER.Rnw"
 mh = readMAPPER(gene="NM_009696", perc="95", models="M00027")
 mh
 query(mh)
 hits(mh)


###################################################
### chunk number 7: example2
###################################################
#line 90 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp1IhW1u/R.INSTALL3bbb6356/RMAPPER/inst/doc/readMAPPER.Rnw"
  mh = readMAPPER(gene="NM_009696", score="3", models="M00027,M00442")
  mh
  query(mh)
  hits(mh)


###################################################
### chunk number 8: help eval=FALSE
###################################################
## #line 99 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp1IhW1u/R.INSTALL3bbb6356/RMAPPER/inst/doc/readMAPPER.Rnw"
##  rmapperHelp()

==> RMAPPER_1.2.0.zip: RMAPPER/doc/readMAPPER.R <==
###################################################
### chunk number 1: setup
###################################################
#line 31 "readMAPPER.Rnw"
library(RMAPPER)
options(warn=-1, width=75, digits=2, scipen=3,  "prompt" = "R> ", "continue" = " ")


###################################################
### chunk number 2: install eval=FALSE
###################################################
## #line 48 "readMAPPER.Rnw"
##  library(RMAPPER)


###################################################
### chunk number 3: factortable eval=FALSE
###################################################
## #line 60 "readMAPPER.Rnw"
##  rmapperFactorTable("*")


###################################################
### chunk number 4: AbaA eval=FALSE
###################################################
## #line 65 "readMAPPER.Rnw"
##  rmapperFactorTable("AbaA")


###################################################
### chunk number 5: Ab eval=FALSE
###################################################
## #line 70 "readMAPPER.Rnw"
##  rmapperFactorTable("Ab")


###################################################
### chunk number 6: example1
###################################################
#line 78 "readMAPPER.Rnw"
 mh = readMAPPER(gene="NM_009696", perc="95", models="M00027")
 mh
 query(mh)
 hits(mh)


###################################################
### chunk number 7: example2
###################################################
#line 90 "readMAPPER.Rnw"
  mh = readMAPPER(gene="NM_009696", score="3", models="M00027,M00442")
  mh
  query(mh)
  hits(mh)


###################################################
### chunk number 8: help eval=FALSE
###################################################
## #line 99 "readMAPPER.Rnw"
##  rmapperHelp()
